CreateProjectFluentBuilder

Struct CreateProjectFluentBuilder 

pub struct CreateProjectFluentBuilder { /* private fields */ }
๐Ÿ‘ŽDeprecated since 11/17/2025: AWS CloudWatch Evidently has been deprecated since 11/17/2025.
Fluent builder constructing a request to CreateProject.

Creates a project, which is the logical object in Evidently that can contain features, launches, and experiments. Use projects to group similar features together.

To update an existing project, use UpdateProject.

Implementations

Source

impl CreateProjectFluentBuilder

pub fn as_input(&self) -> &CreateProjectInputBuilder

Access the CreateProject as a reference.

pub async fn send( self, ) -> Result<CreateProjectOutput, SdkError<CreateProjectError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<CreateProjectOutput, CreateProjectError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn name(self, input: impl Into<String>) -> Self

The name for the project.

pub fn set_name(self, input: Option<String>) -> Self

The name for the project.

pub fn get_name(&self) -> &Option<String>

The name for the project.

pub fn description(self, input: impl Into<String>) -> Self

An optional description of the project.

pub fn set_description(self, input: Option<String>) -> Self

An optional description of the project.

pub fn get_description(&self) -> &Option<String>

An optional description of the project.

pub fn data_delivery(self, input: ProjectDataDeliveryConfig) -> Self

A structure that contains information about where Evidently is to store evaluation events for longer term storage, if you choose to do so. If you choose not to store these events, Evidently deletes them after using them to produce metrics and other experiment results that you can view.

pub fn set_data_delivery(self, input: Option<ProjectDataDeliveryConfig>) -> Self

A structure that contains information about where Evidently is to store evaluation events for longer term storage, if you choose to do so. If you choose not to store these events, Evidently deletes them after using them to produce metrics and other experiment results that you can view.

pub fn get_data_delivery(&self) -> &Option<ProjectDataDeliveryConfig>

A structure that contains information about where Evidently is to store evaluation events for longer term storage, if you choose to do so. If you choose not to store these events, Evidently deletes them after using them to produce metrics and other experiment results that you can view.

pub fn app_config_resource(self, input: ProjectAppConfigResourceConfig) -> Self

Use this parameter if the project will use client-side evaluation powered by AppConfig. Client-side evaluation allows your application to assign variations to user sessions locally instead of by calling the EvaluateFeature operation. This mitigates the latency and availability risks that come with an API call. For more information, see Client-side evaluation - powered by AppConfig.

This parameter is a structure that contains information about the AppConfig application and environment that will be used as for client-side evaluation.

To create a project that uses client-side evaluation, you must have the evidently:ExportProjectAsConfiguration permission.

pub fn set_app_config_resource( self, input: Option<ProjectAppConfigResourceConfig>, ) -> Self

Use this parameter if the project will use client-side evaluation powered by AppConfig. Client-side evaluation allows your application to assign variations to user sessions locally instead of by calling the EvaluateFeature operation. This mitigates the latency and availability risks that come with an API call. For more information, see Client-side evaluation - powered by AppConfig.

This parameter is a structure that contains information about the AppConfig application and environment that will be used as for client-side evaluation.

To create a project that uses client-side evaluation, you must have the evidently:ExportProjectAsConfiguration permission.

pub fn get_app_config_resource(&self) -> &Option<ProjectAppConfigResourceConfig>

Use this parameter if the project will use client-side evaluation powered by AppConfig. Client-side evaluation allows your application to assign variations to user sessions locally instead of by calling the EvaluateFeature operation. This mitigates the latency and availability risks that come with an API call. For more information, see Client-side evaluation - powered by AppConfig.

This parameter is a structure that contains information about the AppConfig application and environment that will be used as for client-side evaluation.

To create a project that uses client-side evaluation, you must have the evidently:ExportProjectAsConfiguration permission.

pub fn tags(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to tags.

To override the contents of this collection use set_tags.

Assigns one or more tags (key-value pairs) to the project.

Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.

Tags don't have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.

You can associate as many as 50 tags with a project.

For more information, see Tagging Amazon Web Services resources.

pub fn set_tags(self, input: Option<HashMap<String, String>>) -> Self

Assigns one or more tags (key-value pairs) to the project.

Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.

Tags don't have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.

You can associate as many as 50 tags with a project.

For more information, see Tagging Amazon Web Services resources.

pub fn get_tags(&self) -> &Option<HashMap<String, String>>

Assigns one or more tags (key-value pairs) to the project.

Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.

Tags don't have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.

You can associate as many as 50 tags with a project.

For more information, see Tagging Amazon Web Services resources.