pub struct TestSegmentPatternFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to TestSegmentPattern.
Use this operation to test a rules pattern that you plan to use to create an audience segment. For more information about segments, see CreateSegment.
Implementations
Sourceimpl TestSegmentPatternFluentBuilder
impl TestSegmentPatternFluentBuilder
Sourcepub fn as_input(&self) -> &TestSegmentPatternInputBuilder
pub fn as_input(&self) -> &TestSegmentPatternInputBuilder
Access the TestSegmentPattern as a reference.
Sourcepub async fn send(
self,
) -> Result<TestSegmentPatternOutput, SdkError<TestSegmentPatternError, HttpResponse>>
pub async fn send( self, ) -> Result<TestSegmentPatternOutput, SdkError<TestSegmentPatternError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<TestSegmentPatternOutput, TestSegmentPatternError, Self>
pub fn customize( self, ) -> CustomizableOperation<TestSegmentPatternOutput, TestSegmentPatternError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn set_pattern(self, input: Option<String>) -> Self
pub fn set_pattern(self, input: Option<String>) -> Self
The pattern to test.
Sourcepub fn get_pattern(&self) -> &Option<String>
pub fn get_pattern(&self) -> &Option<String>
The pattern to test.
Sourcepub fn payload(self, input: impl Into<String>) -> Self
pub fn payload(self, input: impl Into<String>) -> Self
A sample evaluationContext JSON block to test against the specified pattern.
Sourcepub fn set_payload(self, input: Option<String>) -> Self
pub fn set_payload(self, input: Option<String>) -> Self
A sample evaluationContext JSON block to test against the specified pattern.
Sourcepub fn get_payload(&self) -> &Option<String>
pub fn get_payload(&self) -> &Option<String>
A sample evaluationContext JSON block to test against the specified pattern.